@@ -7,10 +7,6 @@ Data class for SPNEGO authentication.
 """
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-import re
-
-from requests.auth import AuthBase
-
 try:
     import kerberos
 except ImportError:
@@ -24,8 +20,10 @@ try:
 except ImportError:
     raise ImportError("Required gssapi package not found.")
 
+from requests.auth import AuthBase
+import re
 
-from h2o.utils.typechecks import assert_is_type
+from h2o.utils.typechecks import (assert_is_type)
 
 __all__ = ("SpnegoAuth", )
 
@@ -38,7 +36,7 @@ class SpnegoAuth(AuthBase):
     def __init__(self, service_principal, mech_oid=kerberos.GSS_MECH_OID_SPNEGO):
         assert_is_type(service_principal, str)
 
-        self._header_regex = re.compile(r'(^|,\s*)Negotiate($|[,\s]+)', re.I)
+        self._header_regex = re.compile('(?:.*,)*\s*Negotiate\s*([^,]*),?', re.I)
 
         self._service_principal = service_principal
         self._mech_oid = mech_oid
