@@ -7,9 +7,11 @@ Collection of utilities for debugging.
 """
 from __future__ import division, print_function, absolute_import, unicode_literals
 
+import colorama
 import inspect
 import re
 import sys
+from colorama import Style, Fore
 from types import ModuleType
 
 from h2o.exceptions import H2OJobCancelled, H2OSoftError
@@ -94,7 +96,7 @@ def _except_hook(exc_type, exc_value, exc_tb):
     else:
         _prev_except_hook(exc_type, exc_value, exc_tb)
 
-    # Everything else is disabled for now, because it generates too much output due to bugs in H2OFrame implementation
+    # Everythin else is disabled for now, because it generates too much output due to bugs in H2OFrame implementation
     return
 
     import linecache
@@ -203,7 +205,8 @@ sys.excepthook = _except_hook
 
 
 def _handle_soft_error(exc_type, exc_value, exc_tb):
-    err("%s: %s" % (exc_type.__name__, exc_value))
+    colorama.init()
+    err((Fore.LIGHTRED_EX + "%s: %s" + Style.RESET_ALL) % (exc_type.__name__, exc_value))
 
     # Convert to the list of frames
     tb = exc_tb
@@ -221,12 +224,16 @@ def _handle_soft_error(exc_type, exc_value, exc_tb):
         highlight = getattr(exc_value, "var_name", None) if i == i0 else None
         args_str = _get_args_str(func, highlight=highlight)
         indent_len = len(exc_type.__name__) + len(fullname) + 6
-        line = indent + ("in " if i == i0 else "   ")
-        line += fullname + "("
+        line = Fore.LIGHTBLACK_EX + indent + ("in " if i == i0 else "   ")
+        line += (Fore.CYAN + fullname + Fore.LIGHTBLACK_EX if i == i0 else fullname) + "("
         line += _wrap(args_str + ") line %d" % frames[i].f_lineno, indent=indent_len)
+        line += Style.RESET_ALL
         err(line)
     err()
 
+    colorama.deinit()
+
+
 
 def _get_method_full_name(func):
     """
@@ -308,7 +315,7 @@ def _get_args_str(func, highlight=None):
     if not func: return ""
     s = str(inspect.signature(func))[1:-1]
     if highlight:
-        s = re.sub(r"\b%s\b" % highlight, "**%s**" % highlight, s)
+        s = re.sub(r"\b%s\b" % highlight, Style.BRIGHT + Fore.WHITE + highlight + Fore.LIGHTBLACK_EX + Style.NORMAL, s)
     return s
 
 
